@@ -13,9 +13,9 @@
 #import "ID3Tagger.h"
 #include <id3/tag.h>
 #include <id3/misc_support.h>
-#import "MP3Header.h"
 #import "WMATagger.h"
 #import "UnicodeWrapper.h"
+#import "MP3Length.h"
 
 @interface ID3Tagger (PrivateAPI)
 // NB these can't be delcared in ID3Tagger.h as would then include id3/tag.h in other files which causes errors
@@ -138,6 +138,7 @@
 			if ([genre characterAtIndex:0] == 40)
 			{
 				NSRange bracketPos = [genre rangeOfCharacterFromSet:[NSCharacterSet characterSetWithCharactersInString:@")"]];
+				
 				if (bracketPos.length == 1 && bracketPos.location == [genre length] - 1)
 				{
 					NSRange numberRange;
@@ -159,13 +160,7 @@
 		[track setYear:[self intFrameContentsFromTag:&myTag frameID:ID3FID_YEAR]];
 		
 		// read the length from the header
-		MP3Header *header = [[MP3Header alloc] init];
-		[track setLength:[header length:filename]];
-		[header release];
-		
-		// why can't I use id3lib like this? always returns NULL
-		/*const Mp3_Headerinfo *header = myTag.GetMp3HeaderInfo();
-		[track setLength:header->time];*/
+		[track setLength:[MP3Length length:filename]];
 		
 		myTag.Clear();
 	
@@ -212,7 +207,15 @@
 			ID3_Field *field = frame->GetField(ID3FN_TEXT);
 			if (field != NULL)
 			{
-				NSData *data = [NSData dataWithBytes:field->GetRawText() length:field->Size()];
+				const char *rawText = field->GetRawText();
+				NSData *data = nil;
+				if (field->Size() == 0)
+					return [NSString stringWithString:@""];
+				if (rawText[field->Size() - 1] == 0)
+					// ignore the NULL terminator
+					data = [NSData dataWithBytes:field->GetRawText() length:(field->Size() - 1)];
+				else
+					data = [NSData dataWithBytes:field->GetRawText() length:field->Size()];
 				NSString *asciiString = [[NSString alloc] initWithData:data encoding:NSISOLatin1StringEncoding];
 				return [asciiString autorelease];
 			}
