@@ -34,6 +34,7 @@
   IBOutlet Preferences *preferences;
 	IBOutlet NJB *theNJB;
 	IBOutlet StatusDisplayer *status;
+	IBOutlet NSButton *connectButton;
 	NJBQueueConsumer *njbQueue;
 	Queue *myQueue;
 	NSLock *myQueueLock;
@@ -41,6 +42,7 @@
 	unsigned previousTabIndex;
 }
 
+- (IBAction)buttonConnect:(id)sender;
 - (void)drawerWriteTag:(Track *)modifiedTrack;
 - (void)initNJB;
 - (id)currentTab;
