@@ -511,7 +511,8 @@
 	}
 	else if ([aResponder class] == [NSMatrix class])
 		objectToSaveTrack = OBJECT_FILE_BROWSER;
-	else if ([aResponder class] == [NSSearchField class])
+	// used to be [aResponder class] == [NSSearchField class]
+	else if (aResponder == njbSearchField)
 	{
 		[drawerController disableAll];
 	}
