@@ -22,7 +22,6 @@
 	BOOL connected;
 	unsigned long long totalDiskSpace;
 	unsigned long long freeDiskSpace;
-	MyMutableArray *cachedTrackList;
 }
 
 - (NJBTransactionResult *)connect;
@@ -33,13 +32,12 @@
 - (void)setStatus:(statusTypes)newStatus;
 - (BOOL)isConnected;
 - (MyMutableArray *)tracks;
-- (MyMutableArray *)cachedTrackList;
 - (MyMutableArray *)dataFiles;
 - (MyMutableArray *)playlists;
-- (NJBTransactionResult *)deleteTrack:(Track *)track;
+- (NJBTransactionResult *)deleteTrack:(NSNumber *)trackID;
 - (NJBTransactionResult *)uploadTrack:(Track *)track;
 - (NJBTransactionResult *)downloadTrack:(Track *)track;
-- (NJBTransactionResult *)changeTrackTagTo:(Track *)newTrack from:(Track *)oldTrack;
+- (NJBTransactionResult *)changeTrackTag:(Track *)track;
 - (NJBTransactionResult *)downloadFile:(DataFile *)dataFile;
 - (NJBTransactionResult *)uploadFile:(DataFile *)dataFile;
 - (NJBTransactionResult *)deleteFile:(NSNumber *)fileID;
@@ -53,7 +51,6 @@
 - (NJBTransactionResult *)updatePlaylist:(Playlist *)playlist;
 - (NJBTransactionResult *)deletePlaylist:(Playlist *)playlist;
 - (NSString *)productName;
-- (NJBTransactionResult *)changeTrackTagTo:(Track *)newTrack from:(Track *)oldTrack;
 
 int progress (u_int64_t sent, u_int64_t total, const char* buf, unsigned len, void *data);
 
