@@ -155,9 +155,14 @@ StatusDisplayer *statusDisplayerGlobal;
 	}
 }
 
+- (NSString *)productName
+{
+	return [NSString stringWithCString:njb->njbid->productName];
+}
+
 - (NSString *)ownerString
 {
-	char *ownerString = NJB_Get_Owner_String (njb);
+	char *ownerString = NJB_Get_Owner_String(njb);
 	if (ownerString == NULL)
 		return nil;
 	NSString *nsOwnerString = [[NSString alloc] initWithUTF8String:ownerString];
@@ -311,7 +316,6 @@ StatusDisplayer *statusDisplayerGlobal;
 		[self updateDiskSpace];
 		return [[[NJBTransactionResult alloc] initWithSuccess:YES] autorelease];
 	}
-		
 }
 
 - (NJBTransactionResult *)deleteFile:(NSNumber *)fileID
