@@ -17,7 +17,6 @@
 	statusTypes status;
 	BOOL displayStatus;
 	BOOL cancelled;
-	NSMutableArray *itemsToCancelIfFail;
 }
 - (void)setTarget:(id)newTarget;
 - (void)setSelector:(SEL)newSelector;
@@ -35,5 +34,4 @@
 - (id)initWithTarget:(id)newTarget withSelector:(SEL)newSelector withObject:(id)newObject withRunInMainThread:(BOOL)newRunInMainThread;
 - (void)cancel;
 - (BOOL)cancelled;
-- (void)cancelItemIfFail:(NJBQueueItem *)item;
 @end
