@@ -21,6 +21,7 @@
 	IBOutlet NSButton *moveTracksDownButton;
 	MyMutableArray *playlists;
 	MyMutableArray *tracksInCurrentPlaylist;
+	BOOL trackListIsUpToDate;
 }
 - (IBAction)addToPlaylist:(id)sender;
 - (IBAction)deleteFromPlaylist:(id)sender;
@@ -35,5 +36,6 @@
 - (NJBTransactionResult *)downloadPlaylists;
 - (void)updateJukeboxPlaylist:(Playlist *)playlist;
 - (void)deleteJukeboxPlaylist:(Playlist *)playlist;
+- (BOOL)trackListIsUpToDate;
 
 @end
