@@ -283,7 +283,20 @@
 		[mainThreadQueue addObject:queueItem];
 		[mainThreadQueueLock unlock];
 		[queueItem release];
+		// a new autorelease pool is required: there is some
+		// limit to the number of autoreleased object that makes
+		// this proxy call crash after 65530 calls.
+		// e.g. this code will crash on the 65531st attempt
+		/*
+		 int i = 0;
+		 for (i = 0; i < 65535; i++)
+		 {
+			 [mainThreadProxy consumeQueue];
+		 }
+		 */
+		NSAutoreleasePool *pool = [[NSAutoreleasePool alloc] init];
 		[mainThreadProxy consumeQueue];
+		[pool release];
 	}
 }
 
