@@ -1,10 +1,6 @@
 #include <string.h>
 #include <libnjb.h>
-#ifdef HAVE_GETOPT_H
 #include <getopt.h>
-#else
-#include <unistd.h>
-#endif
 
 int main (int argc, char **argv)
 {
