@@ -162,6 +162,14 @@ int njb_discover (njb_t *njbs, int limit, int *count)
 				njbs[found].device_type = NJB_DEVICE_DELLDJ2;
 				found ++;
 			}
+			if ( device->descriptor.idVendor == POCKETDJ_VENDOR_ID
+				&& device->descriptor.idProduct ==
+				POCKETDJ_PRODUCT_ID ) {
+				njbs[found].device = device;
+				njbs[found].dev = NULL;
+				njbs[found].device_type = NJB_DEVICE_POCKETDJ;
+				found ++;
+			}
 			device = device->next;
 		}
 		bus = bus->next;
