@@ -14,7 +14,7 @@
 #define __LIBNJB__H
 
 /** The version of this installation of libnjb */
-#define LIBNJB_VERSION 1.3
+#define LIBNJB_VERSION 2.0
 /** A legacy definition - nowadays we always compile for libusb */
 #define LIBNJB_COMPILED_FOR_LIBUSB 1
 
@@ -59,6 +59,7 @@ typedef unsigned __int64 u_int64_t;
 #define NJB_DEVICE_NJBZENTOUCH	0x08 /**< Nomad Jukebox Zen Touch */
 #define NJB_DEVICE_NJBZENMICRO	0x09 /**< Nomad Jukebox Zen Micro */
 #define NJB_DEVICE_DELLDJ2	0x0a /**< Second Generation Dell DJ */
+#define NJB_DEVICE_POCKETDJ     0x0b /**< Dell Pocket DJ */
 /** @} */
 
 /**
@@ -493,6 +494,8 @@ njb_songid_t *NJB_Get_Track_Tag (njb_t *njb);
 int NJB_Replace_Track_Tag(njb_t *njb, u_int32_t trackid, njb_songid_t *songid);
 int NJB_Get_Track (njb_t *njb, u_int32_t trackid, u_int32_t size,
 	const char *path, NJB_Xfer_Callback *callback, void *data);
+int NJB_Get_Track_fd (njb_t *njb, u_int32_t trackid, u_int32_t size,
+	int fd, NJB_Xfer_Callback *callback, void *data);
 int NJB_Send_Track (njb_t *njb, const char *path, njb_songid_t *songid,
 	NJB_Xfer_Callback *callback, void *data, u_int32_t *trackid);
 int NJB_Delete_Track (njb_t *njb, u_int32_t trackid);
