@@ -888,283 +888,335 @@ njb_datafile_t *NJB_Get_Datafile_Tag (njb_t *njb)
  *             user-supplied data with each callback call. It is OK
  *             to set this to NULL of course.
  * @return 0 on success, -1 on failure
+ * @see NJB_Get_Track_fd()
  */
-int NJB_Get_Track (njb_t *njb, u_int32_t fileid, u_int32_t size,
-	const char *path, NJB_Xfer_Callback *callback, void *data)
-{
-	__dsub= "NJB_Get_Track";
-	unsigned char *block = NULL;
-	int fd = 0;
-	u_int32_t bsize, offset;
-	u_int32_t remain = size;
-	int abortxfer = 0;
-	int ret;
-
-	__enter;
-
-	njb_error_clear(njb);
-
-	if (njb->device_type == NJB_DEVICE_NJB1) {
-
-		if ( njb_request_file(njb, fileid) == -1 ) {
-			ret = -1;
-			goto clean_up_and_return;
-		}
-
-		if ( njb_verify_last_command(njb) == -1 ) {
-			NJB_ERROR(njb, EO_XFERDENIED);
-			ret = -1;
-			goto clean_up_and_return;
-		}
-	}
-
+ int NJB_Get_Track (njb_t *njb, u_int32_t fileid, u_int32_t size,
+		    const char *path, NJB_Xfer_Callback *callback, void *data)
+ {
+   
+   __dsub= "NJB_Get_Track";
+   int fd = -1;
+   int ret;
+   
+   __enter;
+   
+   /* big ini chunk */
 #ifdef __WIN32__
-	if ( path && (fd= open(path, O_CREAT|O_TRUNC|O_WRONLY|O_BINARY, 0664)) == -1 ) {
+   if ( path && (fd = open(path, O_CREAT|O_TRUNC|O_WRONLY|O_BINARY, 0664)) == -1 ) {
 #else
-	if ( path && (fd= open(path, O_CREAT|O_TRUNC|O_WRONLY, 0664)) == -1 ) {
+   if ( path && (fd = open(path, O_CREAT|O_TRUNC|O_WRONLY, 0664)) == -1 ) {
 #endif
-		njb_error_add(njb, "open", -1);
-		NJB_ERROR(njb, EO_TMPFILE);
-		ret = -1;
-		goto clean_up_and_return;
-	}
+     njb_error_add(njb, "open", -1);
+     NJB_ERROR(njb, EO_TMPFILE);
+     ret = -1;
+     goto clean_up_and_return;
+   }
 
-	/* File transfer routine for the NJB1 */
-	if (njb->device_type == NJB_DEVICE_NJB1) {
-	        u_int32_t bread = 0;
-		int wasshort = 0;
+   ret = NJB_Get_Track_fd(njb, fileid, size, fd, callback, data);
 
-		block = (unsigned char *) malloc(NJB_XFER_BLOCK_SIZE + NJB_XFER_BLOCK_HEADER_SIZE);
-		if ( block == NULL ) {
-			NJB_ERROR(njb, EO_NOMEM);
-			ret = -1;
-			goto clean_up_and_return;
-		}
-		memset(block, 0, NJB_XFER_BLOCK_SIZE + NJB_XFER_BLOCK_HEADER_SIZE);
-		offset = 0;
-		while (remain != 0 && !abortxfer) {
-		        /* Request as much as possible unless the last chunk is reached */
-			bsize= (remain > NJB_XFER_BLOCK_SIZE) ? NJB_XFER_BLOCK_SIZE : remain;
-
-			bread = 0;
-
-			bread = njb_receive_file_block(njb, offset, bsize, &block[0]);
-			if (bread < bsize + NJB_XFER_BLOCK_HEADER_SIZE) {
-			  wasshort = 1;
-			} else {
-			  wasshort = 0;
-			}
-			
-			/* Handle errors */
-			if (bread == -1) {
-			  ret = -1;
-			  goto clean_up_and_return;
-			}
-			
-			/* Good debug messages */
-			/*
-			fprintf(stdout, "File get: recieved %04x bytes", bread);
-			if (wasshort)
-			  fprintf(stdout, " - short read");
-			fprintf(stdout,"\n");
-			*/
-		
-			/* Write receieved bytes to file */
-			if (path && bread > NJB_XFER_BLOCK_HEADER_SIZE) {
-			  if ( (write(fd, &block[NJB_XFER_BLOCK_HEADER_SIZE], bread-NJB_XFER_BLOCK_HEADER_SIZE)) == -1 ) {
-			    njb_error_add(njb, "write", -1);
-			    NJB_ERROR(njb, EO_WRFILE);
-			    __leave;
-			    ret = -1;
-			    goto clean_up_and_return;
-			  }
-			}
-
-			remain -= (bread-NJB_XFER_BLOCK_HEADER_SIZE);
-			offset += (bread-NJB_XFER_BLOCK_HEADER_SIZE);
-
-			if ( callback != NULL ) {
-			  const char *last_block= (const char *) &block[NJB_XFER_BLOCK_HEADER_SIZE];
-			  if ( callback(offset, size, last_block, bread-NJB_XFER_BLOCK_HEADER_SIZE, data) == -1 ) {
-			    abortxfer = 1;
-			  }
-			}
-		}
-
-		/* This is probably not the right way to abort a file transfer */
-
-		if ( abortxfer ) {
-			njb_transfer_complete(njb);
-			NJB_ERROR(njb, EO_ABORTED);
-			ret = -1;
-			goto clean_up_and_return;
-		} 
-
-		if ( njb_transfer_complete(njb) == -1 ) {
-			NJB_ERROR(njb, EO_XFERERROR);
-			ret = -1;
-			goto clean_up_and_return;
-		}
-	}
-
-	/* Protocol 3 series file transfer routine */
-	if (PROTOCOL3_DEVICE(njb->device_type)) {
-		int confirm_size;
-
-		/* FIXME: add this and test. */
-		/* njb3_ctrl_playing(njb, NJB3_STOP_PLAY); */
-
-		block = (unsigned char *) malloc(NJB3_CHUNK_SIZE);
-		if (block == NULL) {
-		  NJB_ERROR(njb, EO_NOMEM);
-		  ret = -1;
-		  goto clean_up_and_return;
-		}
-
-		/* Start at beginning of file */
-		offset = 0;
-		remain = size;
-
-		while (remain != 0 && abortxfer == 0) {
-		  u_int32_t bwritten;
-		  int chunk_size;
-		  int chunk_remain;
-		  int bread;
-
-		  /*
-		   * Request chunks of size NJB3_CHUNK_SIZE at a time, 
-		   * indexed at an offset into the file. 
-		   */
-		  chunk_size = njb3_request_file_chunk(njb, fileid, offset);
-		  if ( chunk_size == -1 ) {
-		    ret = -1;
-		    goto clean_up_and_return;
-		  }
-
-		  chunk_remain = chunk_size;
-
-		  /* Do NOT break on abort here - all blocks must be sent before 
-		   * cancelling the transfer! */
-		  while (chunk_remain != 0) {
-
-		    /*
-		     * Try to get maximum amount, if we run into a short 
-		     * read, that's OK 
-		     */
-		    /* printf("Requesting chunk size %08X, remaining %08X...\n", NJB3_SUBCHUNK_SIZE, chunk_remain); */
-		    bread = njb3_get_file_block(njb, block, NJB3_GET_FILE_BLOCK_SIZE);
-		    /* Negative value signals error */
-		    if ( bread == -1 ) {
-		      ret = -1;
-		      goto clean_up_and_return;
-		    }
-
-		    /*
-		     * Sometimes the chunk will be one
-		     * byte larger than the reported chunk size.
-		     * The byte is not part of the actual file.
-		     *
-		     * Adjust this downwards as of now...
-		     */
-		    if (bread > chunk_remain) {
-		      int extraneous = bread - chunk_remain;
-		      if (extraneous == 1) {
-			/* printf("LIBNJB: one extraneous byte.\n"); */
-		      }
-		      if (extraneous > 1) {
-			/* This should, however, not happen. */
-			printf("LIBNJB panic: recieved %d extraneous bytes!\n", extraneous);
-		      }
-		      bread = chunk_remain;
-		    }
-		  
-		    /* Write the bytes to the destination file */
-		    if ( (bwritten = write(fd, block, bread) ) == -1 ) {
-		      njb_error_add(njb, "write", -1);
-		      NJB_ERROR(njb, EO_WRFILE);
-		      ret = -1;
-		      goto clean_up_and_return;
-		    } else if ( bwritten != bread ) {
-		      NJB_ERROR(njb, EO_WRFILE);
-		      ret = -1;
-		      goto clean_up_and_return;
-		    }
-
-		    chunk_remain -= bread;
-		    offset += bread;
-
-		    if ( callback != NULL) {
-		      if ( callback(offset, size, NULL, 0, data) == -1 )
-			abortxfer= 1;
-		    }
-		  }
-
-		  /*
-		   * We have recieved a whole chunk or are at the 
-		   * end of the file.
-		   */
-		  if (chunk_size > remain) {
-		    int extraneous = chunk_size - remain;
-		    if (extraneous == 1) {
-		      /* printf("LIBNJB: one extraneous byte in chunk.\n"); */
-		    }
-		    if (extraneous > 1) {
-		      /* This should, however, not happen. */
-		      printf("LIBNJB panic: recieved %d extraneous bytes!\n", extraneous);
-		    }
-		    chunk_size = remain;
-		  }
-		  remain -= chunk_size;
-		  if (remain < 0) {
-		    printf("LIBNJB panic: Remain < 0!\n");
-		    remain = 0;
-		  }
-		}
-
-		/*
-		 * File confirmation is accomplished by requesting 
-		 * file offset set at the file size (e.g. one past 
-		 * the end)
-		 */
-		confirm_size = njb3_request_file_chunk(njb, fileid, size);
-		if (confirm_size != 0) {
-		  ret = -1; /* FIXME: add some error message here */
-		  goto clean_up_and_return;
-		}
-	}
-
-	if ( abortxfer ) {
-	  NJB_ERROR(njb, EO_ABORTED);
-	  ret = -1;
-	  goto clean_up_and_return;
-	} 
-
-	if ( path != NULL ) {
-	       	close(fd);
-		fd = 0;
-	}
-
-	ret = 0;
+   if ( path != NULL ) {
+     close(fd);
+     fd = -1;
+   }
 
 clean_up_and_return:
 
-	if ( block != NULL ) {
-	  free(block);
-	}
-
-	if ( fd != 0 ) {
-	  close(fd);
-	}
-
-	/* On error, remove the partial file. */
-	if ( ret == -1 ) {
-	  unlink(path);
-	}
-
-	__leave;
-	return ret;
+   if ( fd != -1 ) {
+     close(fd);
+   }
+   
+   /* On error, remove the partial file. */
+   if ( ret == -1 ) {
+     unlink(path);
+   }
+   
+   __leave;
+   return ret;
 }
 
+
+/**
+ * This retrieves ("uploads") a track from the device to the host
+ * computer by way of a file descriptor, which is good for e.g.
+ * streaming stuff. The daring type can start playing back audio
+ * from the file descriptor before it is finished. This is also
+ * good for fetching to temporary files, which are often only
+ * given as file descriptors.
+ *
+ * @param njb a pointer to the <code>njb_t</code> object to get
+ *            the track from
+ * @param fileid the unique trackid (also known as file ID, they
+ *               are the same things) as reported by the device
+ *               from e.g. <code>NJB_Get_Track_Tag()</code>.
+ * @param size the size of the track in bytes. You know this size
+ *             from previous calls to <code>NJB_Get_Track_Tag()</code>
+ *             and it is needed among other things for displaying a
+ *             progress bar and for determining that all bytes have been
+ *             correctly retrieved.
+ * @param fd the file descriptor that shall be fed with the track
+ *           contents. The file descriptor must be writable. On
+ *           win32 make sure it is a binary descriptor and not textual.
+ * @param callback a function that will be called repeatedly to report
+ *             progress during transfer, used for e.g. displaying
+ *             progress bars
+ * @param data a voluntary parameter that can associate some 
+ *             user-supplied data with each callback call. It is OK
+ *             to set this to NULL of course.
+ * @return 0 on success, -1 on failure
+ * @see NJB_Get_Track()
+ */
+int NJB_Get_Track_fd (njb_t *njb, u_int32_t fileid, u_int32_t size,
+		      int fd, NJB_Xfer_Callback *callback, void *data)
+{
+  __dsub= "NJB_Get_Track_fd";
+
+  unsigned char *block = NULL;
+  u_int32_t bsize, offset;
+  u_int32_t remain = size;
+  int abortxfer = 0;
+  int ret;
+
+  __enter;
+
+  njb_error_clear(njb);
+
+  if (njb->device_type == NJB_DEVICE_NJB1) {
+
+    if ( njb_request_file(njb, fileid) == -1 ) {
+      ret = -1;
+      goto clean_up_and_return;
+    }
+    
+    if ( njb_verify_last_command(njb) == -1 ) {
+      NJB_ERROR(njb, EO_XFERDENIED);
+      ret = -1;
+      goto clean_up_and_return;
+    }
+  }
+
+  /* File transfer routine for the NJB1 */
+  if (njb->device_type == NJB_DEVICE_NJB1) {
+    u_int32_t bread = 0;
+    int wasshort = 0;
+    
+    block = (unsigned char *) malloc(NJB_XFER_BLOCK_SIZE + NJB_XFER_BLOCK_HEADER_SIZE);
+    if ( block == NULL ) {
+      NJB_ERROR(njb, EO_NOMEM);
+      ret = -1;
+      goto clean_up_and_return;
+    }
+    memset(block, 0, NJB_XFER_BLOCK_SIZE + NJB_XFER_BLOCK_HEADER_SIZE);
+    offset = 0;
+    while (remain != 0 && !abortxfer) {
+      /* Request as much as possible unless the last chunk is reached */
+      bsize= (remain > NJB_XFER_BLOCK_SIZE) ? NJB_XFER_BLOCK_SIZE : remain;
+      
+      bread = 0;
+      
+      bread = njb_receive_file_block(njb, offset, bsize, &block[0]);
+      if (bread < bsize + NJB_XFER_BLOCK_HEADER_SIZE) {
+	wasshort = 1;
+      } else {
+	wasshort = 0;
+      }
+      
+      /* Handle errors */
+      if (bread == -1) {
+	ret = -1;
+	goto clean_up_and_return;
+      }
+      
+      /* Good debug messages */
+      /*
+	fprintf(stdout, "File get: recieved %04x bytes", bread);
+	if (wasshort)
+	fprintf(stdout, " - short read");
+	fprintf(stdout,"\n");
+      */
+      
+      /* Write receieved bytes to file */
+      if (fd > -1 && bread > NJB_XFER_BLOCK_HEADER_SIZE) {
+	if ( (write(fd, &block[NJB_XFER_BLOCK_HEADER_SIZE], bread-NJB_XFER_BLOCK_HEADER_SIZE)) == -1 ) {
+	  njb_error_add(njb, "write", -1);
+	  NJB_ERROR(njb, EO_WRFILE);
+	  __leave;
+	  ret = -1;
+	  goto clean_up_and_return;
+	}
+      }
+      
+      remain -= (bread-NJB_XFER_BLOCK_HEADER_SIZE);
+      offset += (bread-NJB_XFER_BLOCK_HEADER_SIZE);
+      
+      if ( callback != NULL ) {
+	const char *last_block= (const char *) &block[NJB_XFER_BLOCK_HEADER_SIZE];
+	if ( callback(offset, size, last_block, bread-NJB_XFER_BLOCK_HEADER_SIZE, data) == -1 ) {
+	  abortxfer = 1;
+	}
+      }
+    }
+    
+    /* This is probably not the right way to abort a file transfer */
+    
+    if ( abortxfer ) {
+      njb_transfer_complete(njb);
+      NJB_ERROR(njb, EO_ABORTED);
+      ret = -1;
+      goto clean_up_and_return;
+    } 
+    
+    if ( njb_transfer_complete(njb) == -1 ) {
+      NJB_ERROR(njb, EO_XFERERROR);
+      ret = -1;
+      goto clean_up_and_return;
+    }
+  }
+
+  /* Protocol 3 series file transfer routine */
+  if (PROTOCOL3_DEVICE(njb->device_type)) {
+    int confirm_size;
+    
+    /* FIXME: add this and test. */
+    /* njb3_ctrl_playing(njb, NJB3_STOP_PLAY); */
+    
+    block = (unsigned char *) malloc(NJB3_CHUNK_SIZE);
+    if (block == NULL) {
+      NJB_ERROR(njb, EO_NOMEM);
+      ret = -1;
+      goto clean_up_and_return;
+    }
+    
+    /* Start at beginning of file */
+    offset = 0;
+    remain = size;
+    
+    while (remain != 0 && abortxfer == 0) {
+      u_int32_t bwritten;
+      int chunk_size;
+      int chunk_remain;
+      int bread;
+      
+      /*
+       * Request chunks of size NJB3_CHUNK_SIZE at a time, 
+       * indexed at an offset into the file. 
+       */
+      chunk_size = njb3_request_file_chunk(njb, fileid, offset);
+      if ( chunk_size == -1 ) {
+	ret = -1;
+	goto clean_up_and_return;
+      }
+      
+      chunk_remain = chunk_size;
+      
+      /* Do NOT break on abort here - all blocks must be sent before 
+       * cancelling the transfer! */
+      while (chunk_remain != 0) {
+	
+	/*
+	 * Try to get maximum amount, if we run into a short 
+	 * read, that's OK 
+	 */
+	/* printf("Requesting chunk size %08X, remaining %08X...\n", NJB3_SUBCHUNK_SIZE, chunk_remain); */
+	bread = njb3_get_file_block(njb, block, NJB3_GET_FILE_BLOCK_SIZE);
+	/* Negative value signals error */
+	if ( bread == -1 ) {
+	  ret = -1;
+	  goto clean_up_and_return;
+	}
+	
+	/*
+	 * Sometimes the chunk will be one
+	 * byte larger than the reported chunk size.
+	 * The byte is not part of the actual file.
+	 *
+	 * Adjust this downwards as of now...
+	 */
+	if (bread > chunk_remain) {
+	  int extraneous = bread - chunk_remain;
+	  if (extraneous == 1) {
+	    /* printf("LIBNJB: one extraneous byte.\n"); */
+	  }
+	  if (extraneous > 1) {
+	    /* This should, however, not happen. */
+	    printf("LIBNJB panic: recieved %d extraneous bytes!\n", extraneous);
+	  }
+	  bread = chunk_remain;
+	}
+	
+	/* Write the bytes to the destination file */
+	if ( (bwritten = write(fd, block, bread) ) == -1 ) {
+	  njb_error_add(njb, "write", -1);
+	  NJB_ERROR(njb, EO_WRFILE);
+	  ret = -1;
+	  goto clean_up_and_return;
+	} else if ( bwritten != bread ) {
+	  NJB_ERROR(njb, EO_WRFILE);
+	  ret = -1;
+	  goto clean_up_and_return;
+	}
+	
+	chunk_remain -= bread;
+	offset += bread;
+	
+	if ( callback != NULL) {
+	  if ( callback(offset, size, NULL, 0, data) == -1 )
+	    abortxfer= 1;
+	}
+      }
+      
+      /*
+       * We have recieved a whole chunk or are at the 
+       * end of the file.
+       */
+      if (chunk_size > remain) {
+	int extraneous = chunk_size - remain;
+	if (extraneous == 1) {
+	  /* printf("LIBNJB: one extraneous byte in chunk.\n"); */
+	}
+	if (extraneous > 1) {
+	  /* This should, however, not happen. */
+	  printf("LIBNJB panic: recieved %d extraneous bytes!\n", extraneous);
+	}
+	chunk_size = remain;
+      }
+      remain -= chunk_size;
+      if (remain < 0) {
+	printf("LIBNJB panic: Remain < 0!\n");
+	remain = 0;
+      }
+    }
+    
+    /*
+     * File confirmation is accomplished by requesting 
+     * file offset set at the file size (e.g. one past 
+     * the end)
+     */
+    confirm_size = njb3_request_file_chunk(njb, fileid, size);
+    if (confirm_size != 0) {
+      ret = -1; /* FIXME: add some error message here */
+      goto clean_up_and_return;
+    }
+  }
+
+  if ( abortxfer ) {
+    NJB_ERROR(njb, EO_ABORTED);
+    ret = -1;
+    goto clean_up_and_return;
+  }
+  
+  ret = 0;
+  
+clean_up_and_return:
+  
+  if ( block != NULL ) {
+    free(block);
+  }
+  
+  __leave;
+  return ret;
+}
+
+
 /**
  * This is a helper function for sending tracks and files.
  * The <code>NJB_Send_Track()</code> and <code>NJB_Send_File()</code> 
@@ -1506,7 +1558,7 @@ int NJB_Send_Track (njb_t *njb, const char *path, njb_songid_t *songid,
 	}
 
 	/* Make sure the metadata is usable */
-	if (songid_sanity_check(songid) == -1) {
+	if (songid_sanity_check(njb, songid) == -1) {
 	  NJB_ERROR(njb, EO_INVALID);
 	  __leave;
 	  return -1;
@@ -2326,6 +2378,13 @@ int NJB_Delete_Datafile (njb_t *njb, u_int32_t fileid)
 	return 0;
 }
 
+/**
+ * This starts playing a certain track on the device.
+ *
+ * @param njb a pointer to the jukebox object to play the track on.
+ * @param trackid the track to play.
+ * @return 0 on success, -1 on failure.
+ */
 int NJB_Play_Track (njb_t *njb, u_int32_t trackid)
 {
 	__dsub= "NJB_Play_Track";
@@ -2436,13 +2495,13 @@ int NJB_Stop_Play (njb_t *njb)
 	njb_error_clear(njb);
 
 	if (PROTOCOL3_DEVICE(njb->device_type)) {
-	  ret= njb3_stop_play (njb);
+	  ret = njb3_stop_play (njb);
 	  __leave;
 	  return ret;
 	}
 
 	if (njb->device_type == NJB_DEVICE_NJB1) {
-	  ret= njb_stop_play(njb);
+	  ret = njb_stop_play(njb);
 
 	  __leave;
 	  return ret;
@@ -2481,7 +2540,7 @@ int NJB_Elapsed_Time (njb_t *njb, u_int16_t *elapsed, int *change)
 	njb_error_clear(njb);
 
 	if (PROTOCOL3_DEVICE(njb->device_type)) {
-	  ret= njb3_elapsed_time (njb, elapsed, change);
+	  ret = njb3_elapsed_time (njb, elapsed, change);
 	  __leave;
 	  return ret;
 	}
@@ -2499,7 +2558,7 @@ int NJB_Elapsed_Time (njb_t *njb, u_int16_t *elapsed, int *change)
 
 int _file_time (njb_t *njb, const char *path, time_t *ts)
 {
-	__dsub= "_file_time";
+	__dsub = "_file_time";
 	struct stat sb;
 
 	__enter;
@@ -2510,7 +2569,7 @@ int _file_time (njb_t *njb, const char *path, time_t *ts)
 		return -1;
 	}
 
-	*ts= sb.st_mtime;
+	*ts = sb.st_mtime;
 
 	__leave;
 	return 0;
@@ -2529,7 +2588,7 @@ int _file_size (njb_t *njb, const char *path, u_int64_t *size)
 		return -1;
 	}
 
-	*size= sb.st_size;
+	*size = sb.st_size;
 
 	__leave;
 	return 0;
@@ -2622,18 +2681,6 @@ int NJB_Replace_Track_Tag (njb_t *njb, u_int32_t trackid, njb_songid_t *songid)
 
 	njb_error_clear(njb);
 
-	/*
-	 * It's no good to sanity check this, since e.g. the
-	 * codec and size may be missing - we're only UPDATING
-	 * metadata, see.
-	 *
-	  if (songid_sanity_check(songid) == -1) {
-	  NJB_ERROR(njb, EO_INVALID);
-	  __leave;
-	  return -1;
-	  }
-	*/
-
 	/*
 	 * This routine toggles all changed string frames to a
 	 * different name, as changing the name back and forth
@@ -2693,7 +2740,7 @@ int NJB_Replace_Track_Tag (njb_t *njb, u_int32_t trackid, njb_songid_t *songid)
 	  njbttaghdr_t tagh;
 
 	  /* Make sure the metadata is usable for NJB1 */
-	  if (songid_sanity_check(songid) == -1) {
+	  if (songid_sanity_check(njb, songid) == -1) {
 	    NJB_ERROR(njb, EO_BAD_NJB1_REPLACE);
 	    __leave;
 	    return -1;
@@ -2869,6 +2916,12 @@ int NJB_Set_Bitmap(njb_t *njb, const char * path) {
   return 0;
 }
 
+/**
+ * This sends a ping ("are you there?") command to the
+ * device.
+ *
+ * @param njb a pointer to the jukebox object to ping.
+ */
 void NJB_Ping(njb_t *njb)
 {
 	__dsub= "NJB_Ping";
