@@ -1137,7 +1137,15 @@ int njb_get_eax_size (njb_t *njb, u_int32_t *size)
 	return 0;
 }
 
-/* This is the new EAX API */
+/**
+ * This reads in the block with EAX types. It is a byte
+ * chunk which is then interpreted and the EAX effects are
+ * added to a list of effects which is then retrieved by
+ * calls to the <code>njb_get_nexteax()</code> function.
+ * 
+ * @param njb a pointer to the NJB object to use
+ * @param size the previously determined size of the EAX block
+ */
 void njb_read_eaxtypes (njb_t *njb, u_int32_t size)
 {
   __dsub= "njb_read_eaxtypes";
@@ -1147,7 +1155,6 @@ void njb_read_eaxtypes (njb_t *njb, u_int32_t size)
   ssize_t bread;
   u_int32_t actsize;
   unsigned char usize[4];
-
   __enter;
 
   data = (unsigned char *) malloc(size);
@@ -1201,6 +1208,12 @@ void njb_read_eaxtypes (njb_t *njb, u_int32_t size)
   return;
 }
 
+/**
+ * This retrieves an EAX effect from the list of
+ * effects read in by the previous functions.
+ *
+ * @param njb a pointer to the NJB object to use
+ */
 njb_eax_t *njb_get_nexteax(njb_t *njb)
 {
   njb_state_t *state = (njb_state_t *) njb->protocol_state;
@@ -1209,6 +1222,12 @@ njb_eax_t *njb_get_nexteax(njb_t *njb)
   ret = state->next_eax;
   if (ret != NULL) {
     state->next_eax = ret->next;
+  } else {
+    /* 
+     * When we have returned the last EAX type, make sure
+     * there are no dangerous pointers into the void
+     */
+    state->first_eax = NULL;
   }
   return ret;
 }
@@ -1687,7 +1706,7 @@ int njb_elapsed_time (njb_t *njb, u_int16_t *elapsed, int *change)
 
 int njb_replace_track_tag (njb_t *njb, njbttaghdr_t *tagh, void *tag)
 {
-	__dsub= "njb_replace_track_tag";
+	__dsub = "njb_replace_track_tag";
 	u_int16_t msw, lsw;
 	unsigned char *data;
 	ssize_t bwritten;
@@ -1745,7 +1764,7 @@ int njb_adjust_sound(njb_t *njb, u_int8_t effect, int16_t value)
 	memset(data, 0, 3);
 	data[0] = effect;
 
-	printf("Effect %d, sending value %d (%04X)\n", effect, sendvalue, sendvalue);
+	/* printf("Effect %d, sending value %d (%04X)\n", effect, sendvalue, sendvalue); */
 
 	from_16bit_to_njb1_bytes(sendvalue, &data[1]);
 
