@@ -177,8 +177,8 @@ njb_songid_t *songid_unpack (void *data, size_t nbytes)
       /* Depending on value size we construct different frames */
       if (vsize == 2) {
 	/* These are unlikely. NJB1 don't have them much... */
-	printf("LIBNJB confusion: a NJB1 device listed a 16 bit integer for field: %s\n", label);
 	u_int16_t dummy = njb1_bytes_to_16bit(value);
+	printf("LIBNJB confusion: a NJB1 device listed a 16 bit integer for field: %s\n", label);
 	frame = NJB_Songid_Frame_New_Uint16(label, dummy);
       } else if (vsize == 4) {
 	if (!strcmp(label, FR_YEAR) || !strcmp(label, FR_LENGTH) || !strcmp(label, FR_TRACK)) {
@@ -541,7 +541,8 @@ unsigned char *songid_pack3 (njb_songid_t *song, u_int32_t *tagsize)
 	had_codec = 1;
       } else if (!strcmp(frame->data.strval, NJB_CODEC_WMA)) {
 	track_codec = NJB3_CODEC_WMA_ID;
-	tagsize += 6;
+	// change by ral: used to be with no dereferencing *
+	*tagsize += 6;
 	had_codec = 1;
       } else {
 	printf("LIBNJB panic: unknown codec type!\n");
@@ -751,8 +752,9 @@ njb_songid_frame_t *NJB_Songid_Findframe(njb_songid_t *song, const char *label)
  * @param songid the song ID to be checked for sanity
  * @return 0 if the tag is sane, -1 if it is insane
  */
-int songid_sanity_check(njb_songid_t *songid)
+int songid_sanity_check(njb_t *njb, njb_songid_t *songid)
 {
+  __dsub= "songid_sanity_check";
   njb_songid_frame_t *frame;
   u_int8_t has_title = 0;
   u_int8_t size_sane = 0;
@@ -761,6 +763,8 @@ int songid_sanity_check(njb_songid_t *songid)
   u_int8_t has_trackno = 0;
   u_int8_t types_match = 1;
 
+  __enter;
+
   NJB_Songid_Reset_Getframe(songid);
   while ((frame = NJB_Songid_Getframe(songid)) != NULL) {
     if (!strcmp(frame->label, FR_TITLE) && frame->type == NJB_TYPE_STRING) {
@@ -793,9 +797,28 @@ int songid_sanity_check(njb_songid_t *songid)
   }
 
   /* If it is insane, signal back */
-  if (!has_title || !size_sane || !codec_sane || !length_sane || !types_match) {
+  if (!has_title) {
+    njb_error_add_string(njb, subroutinename, "Song title missing.");
+    __leave;
+    return -1;
+  } else  if (!size_sane) {
+    njb_error_add_string(njb, subroutinename, "File is zero bytes long.");
+    __leave;
+    return -1;
+  } else if (!codec_sane) {
+    njb_error_add_string(njb, subroutinename, "Unrecognized codec.");
+    __leave;
+    return -1;
+  } else if (!length_sane) {
+    njb_error_add_string(njb, subroutinename, "Song is zero seconds long.");
+    __leave;
+    return -1;
+  } else if (!types_match) {
+    njb_error_add_string(njb, subroutinename, "Year or protection frame is not 16-bit.");
+    __leave;
     return -1;
   }
+  __leave;
   return 0;
 }
 
